@@ -79,4 +79,18 @@ class Base_Object(object):
             if node and index in node.dict:
                 return node.dict[index]
         return None
+        
+    def __getitem__(self, name):
+        node = self.namespace.get_node(name)
+        if node and 'value' in node.dict:
+            return node.dict['value']
+        elif '.' in name:
+            node, index = name.split('.', 1)
+            node = self.namespace.get_node(node)
+            if node and index in node.dict:
+                return node.dict[index]
+        elif node:
+            return node.dict
+        return None
+        
     
